@@ -9,7 +9,7 @@ use Net::RDAP::Registry;
 use vars qw($VERSION);
 use strict;
 
-$VERSION = 0.5;
+$VERSION = 0.6;
 
 =pod
 
@@ -189,8 +189,7 @@ sub fetch {
 		$url = $arg->href;
 
 	} elsif ($arg->isa('Net::RDAP::Object')) {
-		my @links = grep { 'self' eq $_->rel } $arg->links;
-		$url = shift(@links);
+		$url = $arg->self->href;
 
 	} else {
 		croak("Unable to deal with '$arg'");
@@ -257,8 +256,8 @@ project is hosted here:
 
 =head1 DISTRIBUTION
 
-The L<Net::RDAP> CPAN distribution contains a large number of RDAP-
-related classes that all work together. They are:
+The L<Net::RDAP> CPAN distribution contains a large number of#
+RDAP-related modules that all work together. They are:
 
 =over
 
